@@ -5,7 +5,7 @@ from dataclasses_json import dataclass_json
 
 @dataclass_json
 @dataclass
-class SchemaDiffModificationsValueChange:
+class SchemaDiffValueChange:
     from_: str = field(default=None, metadata={'dataclasses_json': { 'field_name': 'From' }})
     to: str = field(default=None, metadata={'dataclasses_json': { 'field_name': 'To' }})
     
@@ -15,5 +15,5 @@ class SchemaDiffModificationsValueChange:
 class SchemaDiff:
     additions: List[str] = field(default=None, metadata={'dataclasses_json': { 'field_name': 'additions' }})
     deletions: List[str] = field(default=None, metadata={'dataclasses_json': { 'field_name': 'deletions' }})
-    modifications: dict[str, SchemaDiffModificationsValueChange] = field(default=None, metadata={'dataclasses_json': { 'field_name': 'modifications' }})
+    modifications: dict[str, SchemaDiffValueChange] = field(default=None, metadata={'dataclasses_json': { 'field_name': 'modifications' }})
     
